@@ -921,7 +921,8 @@ class EXIF_header:
     def canon_decode_tag(self, value, dict):
         for i in range(1, len(value)):
             x=dict.get(i, ('Unknown', ))
-            print i, x
+            if self.debug:
+                print i, x
             name=x[0]
             if len(x) > 1:
                 val=x[1].get(value[i], 'Unknown')
@@ -961,7 +962,7 @@ def process_file(file, debug=0):
         return {}
 
     # deal with the EXIF info we found
-    if debug:
+    if self.debug:
         print {'I': 'Intel', 'M': 'Motorola'}[endian], 'format'
     hdr=EXIF_header(file, endian, offset, debug)
     ifd_list=hdr.list_IFDs()
@@ -974,19 +975,19 @@ def process_file(file, debug=0):
             thumb_ifd=i
         else:
             IFD_name='IFD %d' % ctr
-        if debug:
+        if self.debug:
             print ' IFD %d (%s) at offset %d:' % (ctr, IFD_name, i)
         hdr.dump_IFD(i, IFD_name)
         # EXIF IFD
         exif_off=hdr.tags.get(IFD_name+' ExifOffset')
         if exif_off:
-            if debug:
+            if self.debug:
                 print ' EXIF SubIFD at offset %d:' % exif_off.values[0]
             hdr.dump_IFD(exif_off.values[0], 'EXIF')
             # Interoperability IFD contained in EXIF IFD
             intr_off=hdr.tags.get('EXIF SubIFD InteroperabilityOffset')
             if intr_off:
-                if debug:
+                if self.debug:
                     print ' EXIF Interoperability SubSubIFD at offset %d:' \
                           % intr_off.values[0]
                 hdr.dump_IFD(intr_off.values[0], 'EXIF Interoperability',
@@ -994,7 +995,7 @@ def process_file(file, debug=0):
         # GPS IFD
         gps_off=hdr.tags.get(IFD_name+' GPSInfoOffset')
         if gps_off:
-            if debug:
+            if self.debug:
                 print ' GPS SubIFD at offset %d:' % gps_off.values[0]
             hdr.dump_IFD(gps_off.values[0], 'GPS', dict=GPS_TAGS)
         ctr+=1
