@@ -7,22 +7,20 @@
 """
 
 from Products.CMFCore.utils import getToolByName
-from Products.Archetypes.debug import log, log_exc
-
-from BTrees.OOBTree import OOBTree
-
+from cStringIO import StringIO 
 
 def getAllPhotos(self):
     catalog = getToolByName(self, 'portal_catalog')
     results = catalog(Type = 'Photo')
-    #log (results)
     results = [r.getObject() for r in results]
     return results
 
 def purgePhotoCache(self):
     """ To be called by an External Method"""
+    out = StringIO() 
     for photo in getAllPhotos(self):
-        log("deleting %s's photo cache" % photo.Title())
-        photo._photos = OOBTree()
-        
-    return "Photo Cache Purged"
+        print >> out, "deleting %s's photo cache" % photo.title_or_id()
+        photo.clearCache()
+    
+    print >> out, "Photo Cache Purged"
+    return out.getvalue() 
