@@ -1,4 +1,4 @@
-import sys
+import sys, os
 import Photo
 from Products.CMFCore import utils, DirectoryView
 
@@ -13,6 +13,7 @@ photo_globals = globals()
 
 DirectoryView.registerDirectory('skins', globals())
 
+
 def initialize(registrar):
     utils.initializeBasesPhase2(z_bases, registrar)
     utils.ContentInit(
